@@ -5,22 +5,25 @@ from pymodelextractor.tests.learners_tests.test_lstarcol_learner import TestLSta
 from pymodelextractor.tests.learners_tests.test_kearns_vazirani_learner import TestKearnsVaziraniLearner
 from pymodelextractor.tests.learners_tests.test_pdfa_lstar_learner import TestPDFALStarLearner
 from pymodelextractor.tests.learners_tests.test_pdfa_lstarcol_learner import TestPDFALStarColLearner
+from pymodelextractor.tests.learners_tests.test_pdfa_kearns_vazirani_learner import TestPDFAKearnsVaziraniLearner
 from tests.learners_tests.test_lambda_star_learner import TestLambdaStarLearnerWithEqualityAlgebra
 from tests.learners_tests.test_pdfa_teachers_pdfa_lstar import TestPDFATeachersLStar
 from tests.learners_tests.test_pdfa_teachers_pdfa_lstar_col import TestPDFATeachersLStarCol
 from tests.learners_tests.test_pac_boolean_model_teacher import TestPACBooleanModelTeachers
-
+from tests.learners_tests.test_pdfa_n_ary_tree_learner import TestPDFANAryTreeLearner
+from tests.learners_tests.test_pdfa_quantization_n_ary_tree_learner import TestPDFAQuantizantionNAryTreeLearner
 
 def run():
-    test_classes_to_run = [TestLStarLearner,
-                           TestLStarColLearner,
-                           TestPDFALStarLearner,
-                           TestKearnsVaziraniLearner,
-                           TestLStarLearner,
-                           TestPDFALStarColLearner,
-                           TestPDFATeachersLStar,
-                           TestPDFATeachersLStarCol]#,
-                           #TestPACBooleanModelTeachers]                      
+    # test_classes_to_run = [TestLStarLearner,
+    #                        TestLStarColLearner,
+    #                        TestPDFALStarLearner,
+    #                        TestKearnsVaziraniLearner,
+    #                        TestLStarLearner,
+    #                        TestPDFALStarColLearner,
+    #                        TestPDFATeachersLStar,
+    #                        TestPDFATeachersLStarCol]#,
+                           #TestPACBooleanModelTeachers]  
+    test_classes_to_run = [ TestPDFAQuantizantionNAryTreeLearner  ]                  
     loader = TestLoader()
     suites_list = []
     for test_class in test_classes_to_run:
